==> jc-1.4.0.tar.gz: java/awt/event/AWTEventListenerProxy.h <==
// public class java.awt.event.AWTEventListenerProxy

// class file dependencies
// @dep_class 8d97f26cc5f874e1 java_awt_event_AWTEventListenerProxy
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_util_EventListenerProxy

#include "java/util/EventListenerProxy.h"

#ifndef _JC_java_awt_event_AWTEventListenerProxy_H_
#define _JC_java_awt_event_AWTEventListenerProxy_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_event_AWTEventListener$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_AWTEventListenerProxy$sub_refs	_jc_java_awt_event_AWTEventListenerProxy$sub_refs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs	_jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$refs	_jc_java_awt_event_AWTEventListenerProxy$refs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$nonrefs	_jc_java_awt_event_AWTEventListenerProxy$nonrefs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$object	_jc_java_awt_event_AWTEventListenerProxy$object;

typedef const struct _jc_java_awt_event_AWTEventListenerProxy$vmethods	_jc_java_awt_event_AWTEventListenerProxy$vmethods;
typedef const struct _jc_java_awt_event_AWTEventListenerProxy$vtable	_jc_java_awt_event_AWTEventListenerProxy$vtable;
typedef const struct _jc_java_awt_event_AWTEventListenerProxy$vtype	_jc_java_awt_event_AWTEventListenerProxy$vtype;

// Constructors
extern void _jc_java_awt_event_AWTEventListenerProxy$method$_init$fca33a3ed7a6d8f0(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *, jlong, struct _jc_object *);

// Virtual methods
extern void _jc_java_awt_event_AWTEventListenerProxy$method$eventDispatched$51fb32721aa8b9fd(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *, struct _jc_java_awt_AWTEvent$object *);
extern jlong _jc_java_awt_event_AWTEventListenerProxy$method$getEventMask$11fe4ff6ca4a44cc(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_AWTEventListenerProxy$method_info$eventDispatched$51fb32721aa8b9fd;
extern _jc_method _jc_java_awt_event_AWTEventListenerProxy$method_info$getEventMask$11fe4ff6ca4a44cc;

// Virtual methods structure
struct _jc_java_awt_event_AWTEventListenerProxy$vmethods {
	void	(*eventDispatched$51fb32721aa8b9fd)(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *, struct _jc_java_awt_AWTEvent$object *);
	jlong	(*getEventMask$11fe4ff6ca4a44cc)(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *);
};

// Vtable
struct _jc_java_awt_event_AWTEventListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
	_jc_java_awt_event_AWTEventListenerProxy$vmethods	java_awt_event_AWTEventListenerProxy;
};

// Vtype
struct _jc_java_awt_event_AWTEventListenerProxy$vtype {
	_jc_type			type;
	_jc_java_awt_event_AWTEventListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_AWTEventListenerProxy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_AWTEventListenerProxy$refs {
    _jc_java_awt_event_AWTEventListenerProxy$sub_refs	java_awt_event_AWTEventListenerProxy;
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs {
	jlong	mask;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_AWTEventListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
    _jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs	java_awt_event_AWTEventListenerProxy;
};

// Object instance structure
struct _jc_java_awt_event_AWTEventListenerProxy$object {
	_jc_java_awt_event_AWTEventListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_AWTEventListenerProxy$vtype	*vtype;
	_jc_java_awt_event_AWTEventListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_AWTEventListenerProxy$vtype _jc_java_awt_event_AWTEventListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_AWTEventListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_AWTEventListenerProxy$class_object;

#endif	/* _JC_java_awt_event_AWTEventListenerProxy_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/AWTEventListenerProxy.h <==
// public class java.awt.event.AWTEventListenerProxy

// class file dependencies
// @dep_class 8d97f26cc5f874e1 java_awt_event_AWTEventListenerProxy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_util_EventListenerProxy

#include "java/util/EventListenerProxy.h"

#ifndef _JC_java_awt_event_AWTEventListenerProxy_H_
#define _JC_java_awt_event_AWTEventListenerProxy_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_event_AWTEventListener$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_AWTEventListenerProxy$sub_refs	_jc_java_awt_event_AWTEventListenerProxy$sub_refs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs	_jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$refs	_jc_java_awt_event_AWTEventListenerProxy$refs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$nonrefs	_jc_java_awt_event_AWTEventListenerProxy$nonrefs;
typedef struct _jc_java_awt_event_AWTEventListenerProxy$object	_jc_java_awt_event_AWTEventListenerProxy$object;

typedef const struct _jc_java_awt_event_AWTEventListenerProxy$vmethods	_jc_java_awt_event_AWTEventListenerProxy$vmethods;
typedef const struct _jc_java_awt_event_AWTEventListenerProxy$vtable	_jc_java_awt_event_AWTEventListenerProxy$vtable;
typedef const struct _jc_java_awt_event_AWTEventListenerProxy$vtype	_jc_java_awt_event_AWTEventListenerProxy$vtype;

// Constructors
extern void _jc_java_awt_event_AWTEventListenerProxy$method$_init$fca33a3ed7a6d8f0(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *, jlong, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_AWTEventListenerProxy$method$eventDispatched$51fb32721aa8b9fd(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_awt_event_AWTEventListenerProxy$method$getEventMask$11fe4ff6ca4a44cc(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_AWTEventListenerProxy$method_info$eventDispatched$51fb32721aa8b9fd;
extern _jc_method _jc_java_awt_event_AWTEventListenerProxy$method_info$getEventMask$11fe4ff6ca4a44cc;

// Virtual methods structure
struct _jc_java_awt_event_AWTEventListenerProxy$vmethods {
	void	(*eventDispatched$51fb32721aa8b9fd)(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
	jlong	(*getEventMask$11fe4ff6ca4a44cc)(_jc_env *, struct _jc_java_awt_event_AWTEventListenerProxy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_AWTEventListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
	_jc_java_awt_event_AWTEventListenerProxy$vmethods	java_awt_event_AWTEventListenerProxy;
};

// Vtype
struct _jc_java_awt_event_AWTEventListenerProxy$vtype {
	_jc_type			type;
	_jc_java_awt_event_AWTEventListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_AWTEventListenerProxy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_AWTEventListenerProxy$refs {
    _jc_java_awt_event_AWTEventListenerProxy$sub_refs	java_awt_event_AWTEventListenerProxy;
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs {
	jlong	mask;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_AWTEventListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
    _jc_java_awt_event_AWTEventListenerProxy$sub_nonrefs	java_awt_event_AWTEventListenerProxy;
};

// Object instance structure
struct _jc_java_awt_event_AWTEventListenerProxy$object {
	_jc_java_awt_event_AWTEventListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_AWTEventListenerProxy$vtype	*vtype;
	_jc_java_awt_event_AWTEventListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_AWTEventListenerProxy$vtype _jc_java_awt_event_AWTEventListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_AWTEventListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_AWTEventListenerProxy$class_object;

#endif	/* _JC_java_awt_event_AWTEventListenerProxy_H_ */
